ErrorType

Enum ErrorType 

pub enum ErrorType {
    Transient,
    Fatal,
}
Types of failure when handling a message. Used by the pub sub framework to handle retries/nacks/dead letter queues/etc.

Variants



Transient

Message processing might succeed if retried after a short delay.

E.g. the message handler encountered a time out when trying to call an API to fulfil the message processing requirements.

The pubsub framework will execute the transient error hook before nacking the message.



Fatal

Message processing will never succeed, no matter how many times you retry or how long you wait.

E.g. the message payload is malformed and cannot be deserialized.

The message will be nacked.