MessageHandler

Struct MessageHandler 

pub struct MessageHandler<Context, Error>
where Context: Send + Sync + 'static, Error: Send + Sync + 'static,
{ /* private fields */ }
A handler processing messages from a RabbitMq queue.

Use MessageHandler::builder to start composing a MessageHandler using a fluent builder API.

Learn by doing

Check out the consumer example on GitHub to see MessageHandler in action.

The example showcases most of the available knobs and what they are used for.

MessageHandler vs ConsumerGroup

A MessageHandler is always part of a ConsumerGroup - it relies on its context and inherits its group-level configuration.

It is possible to:

Implementations

Source

impl<Context, Error> MessageHandler<Context, Error>
where Context: Send + Sync + 'static, Error: Send + Sync + 'static,

pub fn builder<T: Into<String>>( queue_name: T, ) -> MessageHandlerBuilder<Context, Error>

Start building a MessageHandler.

You need to provide the name of the queue you want to consume messages from.