ChannelManager

Struct ChannelManager 

pub struct ChannelManager { /* private fields */ }
ChannelManager implements Manager to manage a pool of Channels.

ChannelManager keeps an internal ConnectionPool in order to reuse connections across channels.

Implementations

Source

impl ChannelManager

pub fn new(connection_pool: ConnectionPool) -> Self

Construct ChannelManager for a Channel.

By default, all channels will have publisher confirmations enabled, but you can opt out using ChannelManager::without_publisher_confirmations

pub fn without_publisher_confirmations(self) -> Self

Disable publisher confirmations.

By default, we enable publisher confirmations, but you can opt out using this flag