pub type ChannelPool = Pool<ChannelManager>;Expand description
ChannelPool pools Channels.
It maintains an internal pool of connections to the rabbitmq instance.
Aliased Type
pub struct ChannelPool { /* private fields */ }pub type ChannelPool = Pool<ChannelManager>;ChannelPool pools Channels.
It maintains an internal pool of connections to the rabbitmq instance.
pub struct ChannelPool { /* private fields */ }